@@ -5,7 +5,9 @@ def add_contact(name, address, step, **kwargs):
     executor =  kwargs.get('executor')
     code, res = redis_add_contact(redis_client, executor, name, address)
     return {
-        'result': { 'code': code, 'content': res }
+        'result': { 'code': code, 'content': res },
+        'action': None, 
+        'next_action': None 
     }
 
 def show_contact_by_name(name, step, **kwargs):
@@ -13,7 +15,9 @@ def show_contact_by_name(name, step, **kwargs):
     executor =  kwargs.get('executor')
     code, res = redis_show_contact(redis_client, executor, name)
     return {
-        'result': { 'code': code, 'content': res }
+        'result': { 'code': code, 'content': res },
+        'action': None, 
+        'next_action': None 
     } 
 
 def show_all_contact(step, **kwargs):
@@ -21,5 +25,7 @@ def show_all_contact(step, **kwargs):
     executor =  kwargs.get('executor')
     code, res = redis_show_contact(redis_client, executor, None)
     return {
-        'result': { 'code': code, 'content': res }
+        'result': { 'code': code, 'content': res },
+        'action': None, 
+        'next_action': None 
     }  
\ No newline at end of file
